Author: jim
Date: Sat Aug  5 17:03:04 2017
New Revision: 1804196

URL: http://svn.apache.org/viewvc?rev=1804196&view=rev
Log:
"Official" release script... sign and prep binaries (basically copy and 
organize them)

Added:
    openoffice/devtools/release-scripts/prep-binaries.sh   (with props)
Modified:
    openoffice/devtools/release-scripts/hash-sign.sh

Modified: openoffice/devtools/release-scripts/hash-sign.sh
URL: 
http://svn.apache.org/viewvc/openoffice/devtools/release-scripts/hash-sign.sh?rev=1804196&r1=1804195&r2=1804196&view=diff
==============================================================================
--- openoffice/devtools/release-scripts/prep-binaries.sh (added)
+++ openoffice/devtools/release-scripts/prep-binaries.sh Sat Aug  5 17:03:04 
2017
@@ -0,0 +1,42 @@
+#!/bin/sh
+# Prepare the OpenOffice download tree: after build and move files.
+# Use hash-sign.sh to sign the binaries (and source files).
+
+if [ ! -d 'main' ] ; then
+  echo "Run from the root of an OpenOffice build tree (the one containing the 
'main' directory)."
+  exit 1
+fi
+
+# TODO: Extend to cover other platforms; this is for Linux only.
+PLATFORMS="unxlngx6.pro unxlngi6.pro unxmaccx.pro"
+PRODUCTS="Apache_OpenOffice Apache_OpenOffice_languagepack 
Apache_OpenOffice_SDK/"
+DESTINATION="../binaries"
+# For future use.
+# FORMATS=`ls -1 main/instsetoo_native/$PLATFORM/$PRODUCT`
+
+# Move all packages to the appropriate location in ../binaries
+for PLATFORM in $PLATFORMS; do
+  echo "Looking for main/instsetoo_native/$PLATFORM"
+  if [ -d "main/instsetoo_native/$PLATFORM" ]; then
+    echo "Working on main/instsetoo_native/$PLATFORM"
+    for PRODUCT in $PRODUCTS; do
+      if [ "$PLATFORM" == "unxmaccx.pro" ]; then
+        FTYPE="dmg"
+      else
+        FTYPE="tar.gz"
+      fi
+      PACKAGES=`ls -1 
main/instsetoo_native/$PLATFORM/$PRODUCT/*/install/*/*.$FTYPE` || echo 
"Warning: no packages found."
+      for PACKAGE in $PACKAGES; do
+        LANGUAGE=`echo "$PACKAGE" | sed 
s!main/instsetoo_native/$PLATFORM/$PRODUCT/[^/]*/install/!! | sed 
s!_download.*!!`
+        FILENAME=`basename $PACKAGE`
+        OUTPUT_DIR="$DESTINATION/$PRODUCT/$LANGUAGE/"
+        # For future use.
+        # FORMAT=`echo $PACKAGE | sed 
s!main/instsetoo_native/$PLATFORM/$PRODUCT/!! | sed s!/.*!!`
+        mkdir -p "$OUTPUT_DIR"
+        echo " -> $OUTPUT_DIR$FILENAME"
+        cp "$PACKAGE" "$OUTPUT_DIR"
+      done
+    done
+  fi
+done
+

Propchange: openoffice/devtools/release-scripts/prep-binaries.sh
------------------------------------------------------------------------------
    svn:executable = *


Reply via email to
--- openoffice/devtools/release-scripts/hash-sign.sh (original)
+++ openoffice/devtools/release-scripts/hash-sign.sh Sat Aug  5 17:03:04 2017
@@ -1,8 +1,7 @@
 #!/bin/sh
 #
 # hash-sign.sh : hash and sign the specified files
 #
 # USAGE: hash-sign.sh file1 file2 ...
 #
 
 user=""
@@ -14,12 +13,8 @@ case "$1" in
     ;;
 esac
 
-allfiles=$*
-
-
-split="---------------------------------------------------------------------"
+allfiles=`find . -type f \\(-name '*.tar.gz' -or -name '*.dmg'\\)`
 
-echo $split
 echo ""
 echo "Generating MD5/SHA1/SHA256 checksum files ..."
 echo ""
@@ -28,13 +23,13 @@ echo ""
 gpg2="`which gpg2 2> /dev/null | head -1`"
 gpg="`which gpg 2> /dev/null | head -1`"
 pgp="`which pgp 2> /dev/null | head -1`"
-openssl="`which openssl 2> /dev/null | head -1`"
 md5sum="`which md5sum 2> /dev/null | head -1`"
 sha1sum="`which sha1sum 2> /dev/null | head -1`"
 sha256sum="`which sha256sum 2> /dev/null | head -1`"
 md5="`which md5 2> /dev/null | head -1`"
 sha1="`which sha1 2> /dev/null | head -1`"
 sha256="`which sha256 2> /dev/null | head -1`"
+openssl="`which openssl 2> /dev/null | head -1`"
 sed="`which gsed 2> /dev/null | head -1`"
 if ! test -x "${sed}"; then
   sed="`which sed 2> /dev/null | head -1`"
@@ -1,8 +1,7 @@
 #!/bin/sh
 #
-# hash-sign.sh : hash and sign the specified files
-#
-# USAGE: hash-sign.sh file1 file2 ...
+# hash-sign.sh : hash and sign the specified files (.tar.gz or .dmg)
+#                in the current dir
 #
 

Added: openoffice/devtools/release-scripts/prep-binaries.sh
URL: 
http://svn.apache.org/viewvc/openoffice/devtools/release-scripts/prep-binaries.sh?rev=1804196&view=auto
==============================================================================